@@ -163,7 +163,7 @@ polarFreq <- function(polar,
              call. = FALSE)
     legend <- list(temp = list(fun = drawOpenKey, args = list(key = legend, 
          draw = FALSE)))
-    names(legend)[1] <- key.position
+    names(legend)[1] <- if(is.null(key$space)) key.position else key$space
 
     xyplot(ws ~ wd | cond,
            xlim = c(-max.ws - 4.0, max.ws + 4.0),
